@@ -22,7 +22,7 @@ $Minilla::DEBUG=1 if $ENV{MINILLA_DEBUG};
 plan skip_all => "No git command" unless which('git');
 plan skip_all => "No cpanm command" unless which('cpanm');
 plan skip_all => "No git configuration" unless `git config user.email` =~ /\@/;
-$ENV{PERL_CPANM_HOME} = tempdir();
+$ENV{PERL_CPANM_HOME} = tempdir(CLEANUP => 1);
 delete $ENV{GIT_CONFIG};
 
 our @EXPORT = (
